QScintilla/Editor.py

changeset 15
f6ccc31d6e72
parent 13
1af94a91f439
child 30
9513afbd57f1
diff -r 092aa8fafa4e -r f6ccc31d6e72 QScintilla/Editor.py
--- a/QScintilla/Editor.py	Sat Jan 02 16:15:57 2010 +0000
+++ b/QScintilla/Editor.py	Sat Jan 02 17:09:08 2010 +0000
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing the editor component of the eric4 IDE.
+Module implementing the editor component of the eric5 IDE.
 """
 
 import os
@@ -44,7 +44,7 @@
 
 class Editor(QsciScintillaCompat):
     """
     Class implementing the editor component of the eric4 IDE.
     
     @signal modificationStatusChanged(boolean, editor) emitted when the
             modification status has changed
@@ -4644,7 +4644,7 @@
                 self.inReopenPrompt = True
                 msg = self.trUtf8(\
                     """<p>The file <b>{0}</b> has been changed while it was opened in"""
-                    """ eric4. Reread it?</p>""").format(self.fileName)
+                    """ eric5. Reread it?</p>""").format(self.fileName)
                 default = QMessageBox.No
                 if self.isModified():
                     msg += self.trUtf8(\
@@ -5322,4 +5322,4 @@
         word = self.getWord(line, index)
         self.spell.ignoreAlways(word)
         if Preferences.getEditor("AutoSpellCheckingEnabled"):
-            self.spell.checkDocumentIncrementally()
+            self.spell.checkDocumentIncrementally()
\ No newline at end of file
@@ -44,7 +44,7 @@
 class Editor(QsciScintillaCompat):
     """
-    Class implementing the editor component of the eric4 IDE.
+    Class implementing the editor component of the eric5 IDE.
     
     @signal modificationStatusChanged(boolean, editor) emitted when the

eric ide

mercurial